NOTE:
ConText rules provided here were gathered from this paper on using medspacy in Dutch:
https://www.medrxiv.org/content/10.1101/2024.03.14.24304289v1.full

The code for this (the rules) are from this GitHub repo:
https://github.com/mi-erasmusmc/medspacy_dutch